@@ -27,7 +27,7 @@ from .managers import ArticleManager
 @python_2_unicode_compatible
 class Article(models.Model):
     tree = models.ForeignKey(
-        Page, verbose_name=_('tree'), related_name='cms_articles', on_delete=models.CASCADE,
+        Page, verbose_name=_('tree'), related_name='cms_articles', on_delete=models.PROTECT,
         help_text=_('The page the article is accessible at.'), limit_choices_to={
             'publisher_is_draft': False,
             'application_urls': 'CMSArticlesApp',
@@ -37,7 +37,8 @@ class Article(models.Model):
         _('template'), max_length=100,
         choices=settings.CMS_ARTICLES_TEMPLATES, default=settings.CMS_ARTICLES_TEMPLATES[0][0],
         help_text=_('The template used to render the content.'))
-    attributes = models.ManyToManyField(Attribute, verbose_name=_('attributes'), related_name='articles', blank=True)
+    attributes = models.ManyToManyField(Attribute, verbose_name=_('attributes'), related_name='articles', blank=True,
+                                        limit_choices_to={'site_id': settings.SITE_ID})
     categories = models.ManyToManyField(Category, verbose_name=_('categories'), related_name='articles', blank=True)
     created_by = models.CharField(_('created by'), max_length=constants.PAGE_USERNAME_MAX_LENGTH, editable=False)
     changed_by = models.CharField(_('changed by'), max_length=constants.PAGE_USERNAME_MAX_LENGTH, editable=False)
